You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openwebbeans.apache.org by ge...@apache.org on 2009/06/06 18:23:51 UTC

svn commit: r782276 - in /incubator/openwebbeans/trunk: ./ samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/ samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/ samples/reservation/src/main/java/org/apa...

Author: gerdogdu
Date: Sat Jun  6 16:23:50 2009
New Revision: 782276

URL: http://svn.apache.org/viewvc?rev=782276&view=rev
Log:
Update API

Added:
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/Any.java   (with props)
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/InjectionException.java   (with props)
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/ResolutionException.java   (with props)
Modified:
    incubator/openwebbeans/trunk/   (props changed)
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LoginBean.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LogoutBean.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/RegisterBean.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminBean.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListBean.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListUser.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserListBean.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserReservationBean.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserUpdateBean.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/ApplicationLog.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/DatabaseLogin.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/LoginController.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/RegisterController.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/admin/AdminController.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/user/UserController.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/intercept/TransactionalInterceptor.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/session/SessionTracker.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/EntityManagerUtil.java
    incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/LogUtil.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AmbiguousResolutionException.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AnnotationLiteral.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/CreationException.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/IllegalProductException.java   (contents, props changed)
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnproxyableResolutionException.java   (contents, props changed)
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnsatisfiedResolutionException.java   (contents, props changed)
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/Interceptor.java   (contents, props changed)
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/InterceptorBindingType.java   (contents, props changed)
    incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/component/JmsComponentImpl.java
    incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/plugin/OpenWebBeansJmsPlugin.java
    incubator/openwebbeans/trunk/webbeans-jpa/src/main/java/org/apache/webbeans/jpa/plugin/OpenWebBeansJpaPlugin.java
    incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/component/resource/TstResourcePersistenceBean.java
    incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/unittests/resource/ResourceInjectionTest.java
    incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansJSFFilter.java
    incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansPhaseListener.java

Propchange: incubator/openwebbeans/trunk/
------------------------------------------------------------------------------
--- svn:ignore (added)
+++ svn:ignore Sat Jun  6 16:23:50 2009
@@ -0,0 +1,2 @@
+target
+.metadata

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LoginBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LoginBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LoginBean.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LoginBean.java Sat Jun  6 16:23:50 2009
@@ -18,9 +18,9 @@
 
 import java.lang.annotation.Annotation;
 
-import javax.annotation.Named;
-import javax.context.RequestScoped;
-import javax.event.Event;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.event.Event;
+import javax.enterprise.inject.Named;
 import javax.event.Fires;
 
 import org.apache.commons.validator.GenericValidator;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LogoutBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LogoutBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LogoutBean.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/LogoutBean.java Sat Jun  6 16:23:50 2009
@@ -16,8 +16,8 @@
  */
 package org.apache.webbeans.reservation.beans;
 
-import javax.annotation.Named;
-import javax.context.RequestScoped;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Named;
 import javax.servlet.http.HttpSession;
 
 import org.apache.webbeans.reservation.util.JSFUtility;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/RegisterBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/RegisterBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/RegisterBean.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/RegisterBean.java Sat Jun  6 16:23:50 2009
@@ -16,11 +16,11 @@
  */
 package org.apache.webbeans.reservation.beans;
 
-import javax.annotation.Named;
 import javax.annotation.PostConstruct;
-import javax.context.RequestScoped;
-import javax.inject.Current;
-import javax.inject.manager.Manager;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
+import javax.enterprise.inject.spi.BeanManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.webbeans.reservation.bindings.ApplicationLog;
@@ -47,7 +47,7 @@
     
     private @Current RegisterController personController;
     
-    private @Current Manager manager; 
+    private @Current BeanManager manager; 
     
     public RegisterBean()
     {

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminBean.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminBean.java Sat Jun  6 16:23:50 2009
@@ -16,9 +16,9 @@
  */
 package org.apache.webbeans.reservation.beans.admin;
 
-import javax.annotation.Named;
-import javax.context.RequestScoped;
-import javax.inject.Current;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
 
 import org.apache.webbeans.reservation.controller.admin.AdminController;
 import org.apache.webbeans.reservation.util.JSFUtility;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListBean.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListBean.java Sat Jun  6 16:23:50 2009
@@ -20,10 +20,10 @@
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.annotation.Named;
-import javax.context.SessionScoped;
+import javax.enterprise.context.SessionScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
 import javax.faces.component.html.HtmlDataTable;
-import javax.inject.Current;
 
 import org.apache.webbeans.reservation.controller.admin.AdminController;
 import org.apache.webbeans.reservation.entity.Hotel;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListUser.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListUser.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListUser.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/admin/AdminListUser.java Sat Jun  6 16:23:50 2009
@@ -20,11 +20,11 @@
 import java.util.List;
 import java.util.Set;
 
-import javax.annotation.Named;
 
-import javax.context.RequestScoped;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
 import javax.faces.component.html.HtmlDataTable;
-import javax.inject.Current;
 
 import org.apache.webbeans.reservation.controller.admin.AdminController;
 import org.apache.webbeans.reservation.entity.Hotel;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserListBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserListBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserListBean.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserListBean.java Sat Jun  6 16:23:50 2009
@@ -19,10 +19,10 @@
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.annotation.Named;
-import javax.context.RequestScoped;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
 import javax.faces.component.html.HtmlDataTable;
-import javax.inject.Current;
 
 import org.apache.webbeans.reservation.controller.user.UserController;
 import org.apache.webbeans.reservation.entity.Reservation;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserReservationBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserReservationBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserReservationBean.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserReservationBean.java Sat Jun  6 16:23:50 2009
@@ -24,12 +24,12 @@
 import java.util.List;
 import java.util.Map;
 
-import javax.annotation.Named;
-import javax.context.Conversation;
-import javax.context.ConversationScoped;
+import javax.enterprise.context.Conversation;
+import javax.enterprise.context.ConversationScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
 import javax.faces.component.html.HtmlDataTable;
 import javax.faces.model.SelectItem;
-import javax.inject.Current;
 
 import org.apache.webbeans.reservation.controller.admin.AdminController;
 import org.apache.webbeans.reservation.controller.user.UserController;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserUpdateBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserUpdateBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserUpdateBean.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/beans/user/UserUpdateBean.java Sat Jun  6 16:23:50 2009
@@ -16,9 +16,9 @@
  */
 package org.apache.webbeans.reservation.beans.user;
 
-import javax.annotation.Named;
-import javax.context.RequestScoped;
-import javax.inject.Current;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
 
 import org.apache.webbeans.reservation.controller.user.UserController;
 import org.apache.webbeans.reservation.entity.User;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/ApplicationLog.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/ApplicationLog.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/ApplicationLog.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/ApplicationLog.java Sat Jun  6 16:23:50 2009
@@ -24,7 +24,7 @@
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
-import javax.inject.BindingType;
+import javax.enterprise.inject.BindingType;
 
 @BindingType
 @Retention(RetentionPolicy.RUNTIME)

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/DatabaseLogin.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/DatabaseLogin.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/DatabaseLogin.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/bindings/DatabaseLogin.java Sat Jun  6 16:23:50 2009
@@ -24,7 +24,7 @@
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
-import javax.inject.BindingType;
+import javax.enterprise.inject.BindingType;
 
 @BindingType
 @Retention(RetentionPolicy.RUNTIME)

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/LoginController.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/LoginController.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/LoginController.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/LoginController.java Sat Jun  6 16:23:50 2009
@@ -20,9 +20,9 @@
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
-import javax.annotation.Named;
-import javax.context.RequestScoped;
-import javax.inject.Current;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
 import javax.persistence.EntityManager;
 import javax.persistence.Query;
 

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/RegisterController.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/RegisterController.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/RegisterController.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/RegisterController.java Sat Jun  6 16:23:50 2009
@@ -16,8 +16,8 @@
  */
 package org.apache.webbeans.reservation.controller;
 
-import javax.context.RequestScoped;
-import javax.inject.Current;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
 import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/admin/AdminController.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/admin/AdminController.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/admin/AdminController.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/admin/AdminController.java Sat Jun  6 16:23:50 2009
@@ -20,9 +20,9 @@
 import java.util.List;
 import java.util.Set;
 
-import javax.annotation.Named;
-import javax.context.RequestScoped;
-import javax.inject.Current;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Named;
 import javax.persistence.EntityManager;
 import javax.persistence.Query;
 

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/user/UserController.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/user/UserController.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/user/UserController.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/controller/user/UserController.java Sat Jun  6 16:23:50 2009
@@ -23,9 +23,9 @@
 
 import javax.annotation.PostConstruct;
 import javax.annotation.PreDestroy;
-import javax.context.RequestScoped;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
 import javax.faces.model.SelectItem;
-import javax.inject.Current;
 import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/intercept/TransactionalInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/intercept/TransactionalInterceptor.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/intercept/TransactionalInterceptor.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/intercept/TransactionalInterceptor.java Sat Jun  6 16:23:50 2009
@@ -16,7 +16,7 @@
  */
 package org.apache.webbeans.reservation.intercept;
 
-import javax.inject.Current;
+import javax.enterprise.inject.Current;
 import javax.interceptor.AroundInvoke;
 import javax.interceptor.Interceptor;
 import javax.interceptor.InvocationContext;

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/session/SessionTracker.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/session/SessionTracker.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/EntityManagerUtil.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/EntityManagerUtil.java Sat Jun  6 16:23:50 2009
@@ -16,10 +16,10 @@
  */
 package org.apache.webbeans.reservation.util;
 
-import javax.context.RequestScoped;
-import javax.inject.Current;
-import javax.inject.Disposes;
-import javax.inject.Produces;
+import javax.enterprise.context.RequestScoped;
+import javax.enterprise.inject.Current;
+import javax.enterprise.inject.Disposes;
+import javax.enterprise.inject.Produces;
 import javax.persistence.EntityManager;
 import javax.persistence.PersistenceContext;
 

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/LogUtil.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/LogUtil.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/LogUtil.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/LogUtil.java Sat Jun  6 16:23:50 2009
@@ -16,9 +16,9 @@
  */
 package org.apache.webbeans.reservation.util;
 
-import javax.annotation.Named;
-import javax.inject.Produces;
-import javax.inject.manager.InjectionPoint;
+import javax.enterprise.inject.Named;
+import javax.enterprise.inject.Produces;
+import javax.enterprise.inject.spi.InjectionPoint;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AmbiguousResolutionException.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AmbiguousResolutionException.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AmbiguousResolutionException.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AmbiguousResolutionException.java Sat Jun  6 16:23:50 2009
@@ -13,9 +13,13 @@
  */
 package javax.enterprise.inject;
 
-import javax.inject.DeploymentException;
-
-public class AmbiguousResolutionException extends DeploymentException
+/**
+ * Ambigous resolution exception. It is thrown when more than one
+ * bean exist for given injection point.
+ *
+ * @version $Rev$ $Date$
+ */
+public class AmbiguousResolutionException extends ResolutionException
 {
     private static final long serialVersionUID = -870939668365532685L;
 

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AnnotationLiteral.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AnnotationLiteral.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AnnotationLiteral.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/AnnotationLiteral.java Sat Jun  6 16:23:50 2009
@@ -20,10 +20,16 @@
 
 import javax.inject.ExecutionException;
 
-
+/**
+ * 
+ *
+ * @param <T> wrapped annotation class
+ * @version $Rev$ $Date$
+ */
 @SuppressWarnings("unchecked")
 public abstract class AnnotationLiteral<T extends Annotation> implements Annotation
 {
+
     private Class<T> annotationType;
 
     protected AnnotationLiteral()
@@ -32,6 +38,7 @@
 
     }
 
+    @Override
     public Class<? extends Annotation> annotationType()
     {
         return annotationType;
@@ -112,20 +119,30 @@
 
     protected Object callMethod(Object instance, Method method)
     {
+        boolean access = method.isAccessible();
+
         try
         {
-            if(!method.isAccessible())
+
+            if (!method.isAccessible())
             {
                 method.setAccessible(true);
             }
-            
-            return method.invoke(instance, new Object[] {});
+
+            return method.invoke(instance, new Object[]
+                    {
+                    });
 
         }
         catch (Exception e)
         {
             throw new ExecutionException("Exception in method call : " + method.getName());
         }
+        finally
+        {
+            method.setAccessible(access);
+        }
+
 
     }
 

Added: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/Any.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/Any.java?rev=782276&view=auto
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/Any.java (added)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/Any.java Sat Jun  6 16:23:50 2009
@@ -0,0 +1,38 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements. See the NOTICE file distributed with this
+ * work for additional information regarding copyright ownership. The ASF
+ * licenses this file to You under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
+ * or agreed to in writing, software distributed under the License is
+ * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the specific language
+ * governing permissions and limitations under the License.
+ */
+package javax.enterprise.inject;
+
+import static java.lang.annotation.ElementType.METHOD;
+import static java.lang.annotation.ElementType.PARAMETER;
+import static java.lang.annotation.ElementType.TYPE;
+import static java.lang.annotation.ElementType.FIELD;
+import static java.lang.annotation.RetentionPolicy.RUNTIME;
+
+import java.lang.annotation.Documented;
+import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
+
+/**
+ * Defines any binding type in the injection point.
+ *
+ * @version $Rev$ $Date$
+ */
+@Target( { TYPE, METHOD, PARAMETER, FIELD })
+@Retention(RUNTIME)
+@Documented
+@BindingType
+public @interface Any
+{
+
+}

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/Any.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/Any.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/CreationException.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/CreationException.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/CreationException.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/CreationException.java Sat Jun  6 16:23:50 2009
@@ -13,9 +13,8 @@
  */
 package javax.enterprise.inject;
 
-import javax.inject.ExecutionException;
 
-public class CreationException extends ExecutionException
+public class CreationException extends InjectionException
 {
     private static final long serialVersionUID = -3952691051791639005L;
 

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/IllegalProductException.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/IllegalProductException.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/IllegalProductException.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/IllegalProductException.java Sat Jun  6 16:23:50 2009
@@ -13,9 +13,13 @@
  */
 package javax.enterprise.inject;
 
-import javax.inject.ExecutionException;
-
-public class IllegalProductException extends ExecutionException
+/**
+ * If return object of the producer method is null and its type
+ * is primitive type then throws this exception.
+ *
+ * @version $Rev$ $Date$
+ */
+public class IllegalProductException extends InjectionException
 {
     private static final long serialVersionUID = 1490337449170464997L;
 

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/IllegalProductException.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Added: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/InjectionException.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/InjectionException.java?rev=782276&view=auto
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/InjectionException.java (added)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/InjectionException.java Sat Jun  6 16:23:50 2009
@@ -0,0 +1,45 @@
+/*
+ *  Copyright 2009 gurkanerdogdu.
+ * 
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ * 
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *  under the License.
+ */
+package javax.enterprise.inject;
+
+/**
+ * Injection exception class.
+ * @version $Rev$ $Date$
+ */
+public class InjectionException extends RuntimeException
+{
+
+    public InjectionException()
+    {
+        
+    }
+
+    public InjectionException(String message, Throwable e)
+    {
+        super(message, e);
+    }
+
+    public InjectionException(Throwable e)
+    {
+        super(e);
+    }
+
+    public InjectionException(String message)
+    {
+        super(message);
+    }
+}

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/InjectionException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/InjectionException.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Added: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/ResolutionException.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/ResolutionException.java?rev=782276&view=auto
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/ResolutionException.java (added)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/ResolutionException.java Sat Jun  6 16:23:50 2009
@@ -0,0 +1,46 @@
+/*
+ *  Copyright 2009 gurkanerdogdu.
+ * 
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ * 
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *  under the License.
+ */
+package javax.enterprise.inject;
+
+/**
+ * Resolution exception class.
+ * 
+ * @version $Rev$ $Date$
+ */
+public class ResolutionException extends InjectionException
+{
+
+    public ResolutionException()
+    {
+        
+    }
+
+    public ResolutionException(String message, Throwable e)
+    {
+        super(message, e);
+    }
+
+    public ResolutionException(Throwable e)
+    {
+        super(e);
+    }
+
+    public ResolutionException(String message)
+    {
+        super(message);
+    }
+}

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/ResolutionException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/ResolutionException.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnproxyableResolutionException.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnproxyableResolutionException.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnproxyableResolutionException.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnproxyableResolutionException.java Sat Jun  6 16:23:50 2009
@@ -13,9 +13,15 @@
  */
 package javax.enterprise.inject;
 
-import javax.inject.DeploymentException;
 
-public class UnproxyableResolutionException extends DeploymentException
+/**
+ * In DI, normal scope type bean class must be proxyable by the container.
+ * If normal scoped bean is not proxyable by the container, it throws
+ * this exception.
+ *
+ * @version $Rev$ $Date$
+ */
+public class UnproxyableResolutionException extends ResolutionException
 {
     private static final long serialVersionUID = 7022231794856380239L;
 

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnproxyableResolutionException.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnsatisfiedResolutionException.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnsatisfiedResolutionException.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnsatisfiedResolutionException.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnsatisfiedResolutionException.java Sat Jun  6 16:23:50 2009
@@ -15,6 +15,12 @@
 
 import javax.inject.DeploymentException;
 
+/**
+ * If injection point is not resolved by the container, it throws
+ * unsatisfied exception.
+ * 
+ * @version $Rev$ $Date$
+ */
 public class UnsatisfiedResolutionException extends DeploymentException
 {
     private static final long serialVersionUID = 8476513814387375212L;

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/UnsatisfiedResolutionException.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/Interceptor.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/Interceptor.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/Interceptor.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/Interceptor.java Sat Jun  6 16:23:50 2009
@@ -28,7 +28,7 @@
 /**
  * Annotation for used defining the interceptors.
  *
- * @version $Rev$ $Id$
+ * @version $Rev$ $Id: Interceptor.java 782259 2009-06-06 13:31:32Z gerdogdu $
  */
 @Retention(RUNTIME)
 @Target({TYPE,METHOD,FIELD})

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/Interceptor.java
------------------------------------------------------------------------------
--- svn:keywords (original)
+++ svn:keywords Sat Jun  6 16:23:50 2009
@@ -1 +1 @@
-Rev Id
+Rev Date

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/InterceptorBindingType.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/InterceptorBindingType.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/InterceptorBindingType.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/InterceptorBindingType.java Sat Jun  6 16:23:50 2009
@@ -23,7 +23,7 @@
 /**
  * Defines binding types for interceptors.
  *
- * @version $Rev$ $Id$
+ * @version $Rev$ $Id: InterceptorBindingType.java 782259 2009-06-06 13:31:32Z gerdogdu $
  */
 @Target(ANNOTATION_TYPE)
 @Retention(RUNTIME)

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/interceptor/InterceptorBindingType.java
------------------------------------------------------------------------------
--- svn:keywords (original)
+++ svn:keywords Sat Jun  6 16:23:50 2009
@@ -1 +1 @@
-Rev Id
+Rev Date

Modified: incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/component/JmsComponentImpl.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/component/JmsComponentImpl.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/component/JmsComponentImpl.java (original)
+++ incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/component/JmsComponentImpl.java Sat Jun  6 16:23:50 2009
@@ -18,7 +18,7 @@
 
 import java.lang.reflect.Method;
 
-import javax.context.CreationalContext;
+import javax.enterprise.context.spi.CreationalContext;
 import javax.jms.MessageConsumer;
 import javax.jms.MessageProducer;
 import javax.jms.Session;

Modified: incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/plugin/OpenWebBeansJmsPlugin.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/plugin/OpenWebBeansJmsPlugin.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/plugin/OpenWebBeansJmsPlugin.java (original)
+++ incubator/openwebbeans/trunk/webbeans-jms/src/main/java/org/apache/webbeans/jms/plugin/OpenWebBeansJmsPlugin.java Sat Jun  6 16:23:50 2009
@@ -19,7 +19,7 @@
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Type;
 
-import javax.inject.manager.InjectionPoint;
+import javax.enterprise.inject.spi.InjectionPoint;
 
 import org.apache.webbeans.container.ManagerImpl;
 import org.apache.webbeans.exception.WebBeansConfigurationException;

Modified: incubator/openwebbeans/trunk/webbeans-jpa/src/main/java/org/apache/webbeans/jpa/plugin/OpenWebBeansJpaPlugin.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-jpa/src/main/java/org/apache/webbeans/jpa/plugin/OpenWebBeansJpaPlugin.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-jpa/src/main/java/org/apache/webbeans/jpa/plugin/OpenWebBeansJpaPlugin.java (original)
+++ incubator/openwebbeans/trunk/webbeans-jpa/src/main/java/org/apache/webbeans/jpa/plugin/OpenWebBeansJpaPlugin.java Sat Jun  6 16:23:50 2009
@@ -16,8 +16,6 @@
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Type;
 
-import javax.inject.BindingType;
-
 import org.apache.webbeans.exception.WebBeansConfigurationException;
 import org.apache.webbeans.jpa.spi.JPAService;
 

Modified: incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/component/resource/TstResourcePersistenceBean.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/component/resource/TstResourcePersistenceBean.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/component/resource/TstResourcePersistenceBean.java (original)
+++ incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/component/resource/TstResourcePersistenceBean.java Sat Jun  6 16:23:50 2009
@@ -13,7 +13,7 @@
  */
 package org.apache.webbeans.test.component.resource;
 
-import javax.annotation.Named;
+import javax.enterprise.inject.Named;
 import javax.persistence.EntityManager;
 import javax.persistence.EntityManagerFactory;
 import javax.persistence.PersistenceContext;

Modified: incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/unittests/resource/ResourceInjectionTest.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/unittests/resource/ResourceInjectionTest.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/unittests/resource/ResourceInjectionTest.java (original)
+++ incubator/openwebbeans/trunk/webbeans-jpa/src/test/java/org/apache/webbeans/test/unittests/resource/ResourceInjectionTest.java Sat Jun  6 16:23:50 2009
@@ -13,7 +13,7 @@
  */
 package org.apache.webbeans.test.unittests.resource;
 
-import javax.inject.manager.Manager;
+import javax.enterprise.inject.spi.BeanManager;
 import javax.persistence.EntityManager;
 import javax.persistence.EntityManagerFactory;
 
@@ -28,7 +28,7 @@
 
 public class ResourceInjectionTest extends TestContext
 {
-    Manager container = null;
+    BeanManager container = null;
 
     public ResourceInjectionTest()
     {

Modified: incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansJSFFilter.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansJSFFilter.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansJSFFilter.java (original)
+++ incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansJSFFilter.java Sat Jun  6 16:23:50 2009
@@ -15,8 +15,8 @@
 
 import java.io.IOException;
 
-import javax.context.Conversation;
-import javax.inject.manager.Bean;
+import javax.enterprise.context.Conversation;
+import javax.enterprise.inject.spi.Bean;
 import javax.servlet.Filter;
 import javax.servlet.FilterChain;
 import javax.servlet.FilterConfig;

Modified: incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansPhaseListener.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansPhaseListener.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansPhaseListener.java (original)
+++ incubator/openwebbeans/trunk/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/WebBeansPhaseListener.java Sat Jun  6 16:23:50 2009
@@ -13,7 +13,7 @@
  */
 package org.apache.webbeans.jsf;
 
-import javax.context.ConversationScoped;
+import javax.enterprise.context.ConversationScoped;
 import javax.faces.component.UIViewRoot;
 import javax.faces.event.PhaseEvent;
 import javax.faces.event.PhaseId;
--- incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/session/SessionTracker.java (original)
+++ incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/session/SessionTracker.java Sat Jun  6 16:23:50 2009
@@ -19,13 +19,14 @@
 
 import java.io.Serializable;
 
-import javax.annotation.Named;
-import javax.context.SessionScoped;
 
 import org.apache.webbeans.reservation.entity.User;
 import org.apache.webbeans.reservation.events.LoggedInEvent;
-import javax.event.Observes;
-import javax.inject.manager.Manager;
+
+import javax.enterprise.context.SessionScoped;
+import javax.enterprise.event.Observes;
+import javax.enterprise.inject.Named;
+import javax.enterprise.inject.spi.BeanManager;
 
 @SessionScoped
 @Named
@@ -37,7 +38,7 @@
      
     /**
      * When event fires, this observer method is called
      * by the {@link Manager} interface.
      * 
      * @param loggedInEvent event 
      */
@@ -37,7 +38,7 @@
     /**
      * When event fires, this observer method is called
-     * by the {@link Manager} interface.
+     * by the {@link BeanManager} interface.
      * 
      * @param loggedInEvent event 

Modified: incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/EntityManagerUtil.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/EntityManagerUtil.java?rev=782276&r1=782275&r2=782276&view=diff
==============================================================================